# -*- coding: iso-8859-15 -*-
#    Plot of 300 highest rewards depending on number of works, min reward
#    and Zipf's law parameter
#    To generate figure 7-3 of "Sharing", one has to run:
#    python figure7-3.py 4200000 8230000 13750000 40.0 1.0 0.9 0.8
#
#    Copyright (C) 2010 - Philippe Aigrain
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA

from pylab import *

def harmonic(s,n):
  k=0.0;
  for i in arange (1.0,n+1.0,1.0):
    k += pow(i,-s);
  return k;  

def main(argv):
  if len(argv) < 8:
    print ("Usage: %s <3 number of works> <min reward> <3 Zipf's law parameter>") % argv[0]
    print "Various options for rewards"
    sys.exit(0)
  # Args
  N1 = float(argv[1])
  N2 = float(argv[2])
  N3 = float(argv[3])
  minreward = float(argv[4])
  a1 = float(argv[5])
  a2 = float(argv[6])
  a3 = float(argv[7])
  # Inits
  rewards1 = zeros(500,float)
  rewards2 = zeros(500,float)
  rewards3 = zeros(500,float)
  totreward1 = minreward * harmonic(a1,N1) * pow(N1,a1)
  totreward2 = minreward * harmonic(a2,N2) * pow(N2,a2)
  totreward3 = minreward * harmonic(a3,N3) * pow(N3,a3)
  uselevel1 = pow(N1,-a1)/harmonic(a1,N1)
  uselevel2 = pow(N2,-a2)/harmonic(a2,N2)
  uselevel3 = pow(N3,-a3)/harmonic(a3,N3)
  # computation of normalized rewards
  for i in arange(0.0,500.0,1.0):
    rewards1[i] =  pow(i+1.0,-a1) * pow(N1,a1) * minreward
    rewards2[i] =  pow(i+1.0,-a2) * pow(N2,a2) * minreward
    rewards3[i] =  pow(i+1.0,-a3) * pow(N3,a3) * minreward
  ind = range(1,int(500)+1,1)
  plotpar = {'axes.labelsize': 24,
               'text.fontsize': 24,
               'legend.fontsize': 20,
               'xtick.labelsize': 22,
               'ytick.labelsize': 22,
               'text.usetex': False}
  rcParams.update(plotpar)
  close(1)
  figure(num=1, figsize=(16,12), facecolor='w', edgecolor='k')
# Plotting
# Replace by next line for BW figure
# l1,l2,l3= plot(ind,rewards1,'k-.',ind,rewards2,'k--',ind,rewards3,'k-',antialiased=True,lw=2)
  l1,l2,l3= plot(ind,rewards1,'b-',ind,rewards2,'g--',ind,rewards3,'r-.',antialiased=True,lw=2)
  xlabel('decreasing popularity ranks')
  yaxislabel = 'reward in US $'
  ylabel(yaxislabel)
  legend( (l1,l2,l3),  ('Concentrated','Intermediate','Diverse'), loc='upper center')
  ylim(0.0, 5000000.0)
  xlim(1.0, 300.0)
  grid(True)
  savefig('illustration.png')
  show()



if __name__ == '__main__':
  main(sys.argv)
